package cursos;

import fundamentos.*;

/**
 * Title:        Curso<p>
 * Description:  Clase que almacena un curso formado por alumnos de la
 *               clase Alumno<p>
 * Company:      Universidad de Cantabria<p>
 * @author       Michael Gonzalez
 */

public class Curso {
  
  // La estructura de datos es un array del que se usan las
  // primeras num casillas
  // num es el numero actual de alumnos almacenados
  private Alumno[] losAlumnos; 
  private int num;

  /**
   * Constructor que pone el numero de alumnos a cero
   * y crea el array
   */
  public Curso(int maxAlumnos) {
    num=0;
    losAlumnos = new Alumno[maxAlumnos];
  }

  /**
   * Anade un alumno al curso,
   */
  public void anade() {
    if (num==losAlumnos.length) {
        Mensaje mensaje=new Mensaje();
        mensaje.escribe("Demasiados alumnos");
    } else {
        num++;
        Alumno nuevo=new Alumno();
        nuevo.leeDatos();
        losAlumnos[num-1]=nuevo;
    }
  }



  /**
   * Busca un alumno, cuyo dni se pide por teclado
   *    retorna -1 si no existe
   *    retorna el numero del alumno si lo encuentra
   */
  private int busca(String dniBuscado) {
      for (int i=0; i<num; i++) {
         if (losAlumnos[i].dni().equals(dniBuscado)) {
            return i;
         }
      }
      // no encontrado
      return -1;
  }

  /**
   * Muestra los datos de un alumno, cuyo dni se pide por teclado
   */
  public void muestra() {

    if (num==0) {
        Mensaje mensaje = new Mensaje();
        mensaje.escribe("No hay alumnos");
    } else {
        Lectura leeDni = new Lectura("Lectura DNI");
        String dniBuscado;
        leeDni.creaEntrada("DNI","");
        leeDni.esperaYCierra("Introduce DNI del alumno buscado");
        dniBuscado=leeDni.leeString("DNI");
        int i=busca(dniBuscado);
        if (i>=0) {
            losAlumnos[i].escribeDatos();
        } else {
            Mensaje mensaje = new Mensaje();
            mensaje.escribe("Alumno no existe");
        }
    }
  }
  
  /**
   * Muestra todos los alumnos
   */
  public void muestraTodos() {
    for (int i=0; i<num;i++) {    
        System.out.println(losAlumnos[i].aTexto());   
    }
  }


}
